"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useNotionBlock = exports.defineNotionProps = void 0;
var _utils = require("@/lib/utils");
var _vue = require("vue");
const defineNotionProps = {
  blockMap: {
    type: Object,
    required: true
  },
  contentId: {
    type: String,
    required: false
  },
  contentIndex: {
    type: Number,
    default: 0
  },
  embedAllow: {
    type: String,
    default: "fullscreen"
  },
  fullPage: {
    type: Boolean,
    default: false
  },
  hideList: {
    type: Array,
    default: () => []
  },
  level: {
    type: Number,
    default: 0
  },
  mapImageUrl: {
    type: Function,
    default: _utils.defaultMapImageUrl
  },
  mapPageUrl: {
    type: Function,
    default: _utils.defaultMapPageUrl
  },
  pageLinkOptions: Object,
  pageLinkTarget: {
    type: String,
    default: "_self"
  },
  prism: {
    type: Boolean,
    default: false
  },
  katex: {
    type: Boolean,
    default: false
  },
  textLinkTarget: {
    type: String,
    default: "_blank"
  }
};
exports.defineNotionProps = defineNotionProps;
const useNotionBlock = props => {
  const block = (0, _vue.computed)(() => {
    const id = props.contentId || Object.keys(props.blockMap)[0];
    return props.blockMap[id];
  });
  const pass = (0, _vue.computed)(() => {
    return {
      blockMap: props.blockMap,
      contentId: props.contentId,
      contentIndex: props.contentIndex,
      embedAllow: props.embedAllow,
      fullPage: props.fullPage,
      hideList: props.hideList,
      level: props.level,
      mapImageUrl: props.mapImageUrl,
      mapPageUrl: props.mapPageUrl,
      pageLinkOptions: props.pageLinkOptions,
      prism: props.prism,
      katex: props.katex
    };
  });
  const f = (0, _vue.computed)(() => {
    return {
      block_aspect_ratio: block.value?.value?.format?.block_aspect_ratio,
      block_height: block.value?.value?.format?.block_height || 1,
      block_width: block.value?.value?.format?.block_width || 1,
      block_color: block.value?.value?.format?.block_color,
      bookmark_icon: block.value?.value?.format?.bookmark_icon,
      bookmark_cover: block.value?.value?.format?.bookmark_cover,
      display_source: block.value?.value?.format?.display_source
    };
  });
  const format = (0, _vue.computed)(() => block.value?.value.format);
  const properties = (0, _vue.computed)(() => block.value?.value.properties);
  const icon = (0, _vue.computed)(() => format.value?.page_icon);
  const width = (0, _vue.computed)(() => format.value?.block_width);
  const title = (0, _vue.computed)(() => properties.value?.title);
  const caption = (0, _vue.computed)(() => properties.value?.caption);
  const description = (0, _vue.computed)(() => properties.value?.description);
  const type = (0, _vue.computed)(() => {
    return block.value?.value.type;
  });
  const visible = (0, _vue.computed)(() => {
    return type.value ? !props.hideList?.includes(type.value) : false;
  });
  const hasPageLinkOptions = (0, _vue.computed)(() => {
    return props.pageLinkOptions?.component && props.pageLinkOptions?.href;
  });
  const parent = (0, _vue.computed)(() => {
    return props.blockMap[block.value?.value.parent_id];
  });
  const isType = t => {
    if (Array.isArray(t)) {
      return visible.value && t.includes(type.value);
    }
    return visible.value && type.value === t;
  };
  const blockColorClass = (suffix = "") => {
    const blockColor = block.value?.value?.format?.block_color;
    return blockColor ? `notion-${blockColor}${suffix}` : void 0;
  };
  const pageLinkProps = id => {
    return props.pageLinkOptions ? {
      [props.pageLinkOptions.href]: props.mapPageUrl(id)
    } : {};
  };
  return {
    props,
    block,
    pass,
    f,
    format,
    properties,
    icon,
    width,
    title,
    caption,
    description,
    type,
    visible,
    hasPageLinkOptions,
    parent,
    isType,
    blockColorClass,
    pageLinkProps
  };
};
exports.useNotionBlock = useNotionBlock;