"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTextContent = exports.getListNumber = exports.defaultMapPageUrl = exports.defaultMapImageUrl = void 0;
const getTextContent = text => {
  return text.reduce((prev, current) => prev + current[0], "");
};
exports.getTextContent = getTextContent;
const groupBlockContent = blockMap => {
  const output = [];
  let lastType = void 0;
  let index = -1;
  Object.keys(blockMap).forEach(id => {
    blockMap[id].value.content?.forEach(blockId => {
      const blockType = blockMap[blockId]?.value?.type;
      if (blockType && blockType !== lastType) {
        index++;
        lastType = blockType;
        output[index] = [];
      }
      output[index].push(blockId);
    });
    lastType = void 0;
  });
  return output;
};
const getListNumber = (blockId, blockMap) => {
  const groups = groupBlockContent(blockMap);
  const group = groups.find(g => g.includes(blockId));
  if (!group) {
    return;
  }
  return group.indexOf(blockId) + 1;
};
exports.getListNumber = getListNumber;
const defaultMapImageUrl = (image = "", block) => {
  const url = new URL(`https://www.notion.so${image.startsWith("/image") ? image : `/image/${encodeURIComponent(image)}`}`);
  if (block && !image.includes("/images/page-cover/")) {
    const table = block.value.parent_table === "space" ? "block" : block.value.parent_table;
    url.searchParams.set("table", table);
    url.searchParams.set("id", block.value.id);
    url.searchParams.set("cache", "v2");
  }
  return url.toString();
};
exports.defaultMapImageUrl = defaultMapImageUrl;
const defaultMapPageUrl = (pageId = "") => {
  pageId = pageId.replace(/-/g, "");
  return `/${pageId}`;
};
exports.defaultMapPageUrl = defaultMapPageUrl;